@@ -11,15 +11,13 @@
 #include <QDebug>
 
 Event::Event()
-    : wid(0)
-    , type(Accessed)
+    : type(Accessed)
     , timestamp(QDateTime::currentDateTime())
 {
 }
 
-Event::Event(const QString &vApplication, quintptr vWid, const QString &vUri, int vType)
+Event::Event(const QString &vApplication, const QString &vUri, int vType)
     : application(vApplication)
-    , wid(vWid)
     , uri(vUri)
     , type(vType)
     , timestamp(QDateTime::currentDateTime())
@@ -37,7 +35,7 @@ Event Event::deriveWithType(Type type) const
 
 bool Event::operator==(const Event &other) const
 {
-    return application == other.application && wid == other.wid && uri == other.uri && type == other.type && timestamp == other.timestamp;
+    return application == other.application && uri == other.uri && type == other.type && timestamp == other.timestamp;
 }
 
 QString Event::typeName() const
@@ -51,10 +49,6 @@ QString Event::typeName() const
         return QStringLiteral("Modified");
     case Closed:
         return QStringLiteral("Closed");
-    case FocussedIn:
-        return QStringLiteral("FocussedIn");
-    case FocussedOut:
-        return QStringLiteral("FocussedOut");
     default:
         return QStringLiteral("Other");
     }
@@ -63,7 +57,7 @@ QString Event::typeName() const
 QDebug operator<<(QDebug dbg, const Event &e)
 {
 #ifndef QT_NO_DEBUG_OUTPUT
-    dbg << "Event(" << e.application << e.wid << e.typeName() << e.uri << ":" << e.timestamp << ")";
+    dbg << "Event(" << e.application << e.typeName() << e.uri << ":" << e.timestamp << ")";
 #else
     Q_UNUSED(e);
 #endif
